def mathias():
    print("Hei Mathias")
    
def brian():
    print("Hei Brian")

def mango():
    print("Mangooooooo")
    
def mango2():
    print("Mer mangoooo")
    
def mango3():
    print("Enda mer mangoooo")